MemStore

Struct MemStore 

pub struct MemStore {
    pub enable_saving_committed: AtomicBool,
    /* private fields */
}
An in-memory storage system implementing the RaftStorage trait.

Fields

enable_saving_committed: AtomicBool

Saving committed log id is optional in Openraft.

This flag switches on the saving for testing purposes.

Implementations

Source

impl MemStore

pub fn new() -> Self

Create a new MemStore instance.

pub async fn new_async() -> Arc<Self>

pub async fn drop_snapshot(&self)

Remove the current snapshot.

This method is only used for testing purposes.

pub async fn get_state_machine(&self) -> MemStoreStateMachine

Get a handle to the state machine for testing purposes.

pub async fn clear_state_machine(&self)

Clear the state machine for testing purposes.

pub fn set_blocking(&self, block: BlockOperation, d: Duration)

Block an operation for testing purposes.

pub fn get_blocking(&self, block: &BlockOperation) -> Option<Duration>

Get the blocking flag for an operation.

pub fn clear_blocking(&mut self, block: BlockOperation)

Clear a blocking flag for an operation.